@@ -24,6 +24,7 @@ class OmekaSGateway(object):
     def create_page(self, data):
         uri, params = self.get_request_info('site_pages')
         r = requests.post(uri, params=params, json=data)
+        r.raise_for_status()
         return r.json()
 
     def get_page_by_slug(self, slug):
@@ -34,7 +35,9 @@ class OmekaSGateway(object):
 
     def update_page(self, id_, data):
         uri, params = self.get_request_info('site_pages/{}'.format(id_))
-        requests.put(uri, params=params, json=data)
+        r = requests.put(uri, params=params, json=data)
+        r.raise_for_status()
+        return r.json()
 
     def list_site_pages(self):
         uri, params = self.get_request_info('site_pages')
